import os
import re

# Full or related path to in and out folders

INPUT_DIR = "input"     # or example "SteamLibrary/steamapps/common/Eco/Eco_Data/Server/Mods/__core__/AutoGen
OUTPUT_DIR = "output"   # or example "SteamLibrary/steamapps/common/Eco/Eco_Data/Server/Mods/UserCode/AutoGen

# File extensions to process
EXT = [".cs"]
# Preferences "what value to find", [factor, value type(int or float)]
# factor 1.5 means +50%, factor 0.8 means -20%
PREFS = {
    "MaxStackSize": [1.5, int],
    "MaturityAgeDays": [0.8, float],
    "Weight": [2.0, int],
    "Fuel": [1.2, int]
    
}

if not os.path.exists(OUTPUT_DIR):
    os.makedirs(OUTPUT_DIR)

if not os.path.exists(INPUT_DIR):
    print("Input dir does not exist!", INPUT_DIR)
    exit(-1)


def replace_value(st, factor, value_type=float):
    pat = r"[0-9]+\.?[0-9]*"
    value = re.search(pat, st)
    if value:
        value = value_type(value.group(0))
        new_value = value_type(round(value * factor, 1))
    print(f"Replace the {value} with {new_value}")
    st = re.sub(pat, str(new_value), st)
    return st


for file in os.listdir(INPUT_DIR):
    if any(ext in file.lower() for ext in EXT):
        print(file)
        with open(os.path.join(INPUT_DIR, file), "r") as in_f, open(os.path.join(OUTPUT_DIR, file), "w+") as out_f:
            for line in in_f:
                for key in PREFS.keys():
                    if key in line:
                        print(key, "found!")
                        line = replace_value(line, PREFS[key][0], PREFS[key][1])
                out_f.write(line)

for filename in os.listdir(OUTPUT_DIR):
    infilename = os.path.join(OUTPUT_DIR,filename)
    if not os.path.isfile(infilename): continue
    oldbase = os.path.splitext(filename)
    newname = infilename.replace('.cs', '.override.cs')
    output = os.rename(infilename, newname)


# Copyright (c) 2021 Gamers Community Place

#  This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.

#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.

#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <https://www.gnu.org/licenses/>.
